@@ -2,17 +2,22 @@ from functools import partial
 
 import regex
 
+from collections import defaultdict
+
 from ....config import CRUNCHYROLL, KAMYROLL_API
 from ..crunchyroll import metadata_fetcher
-from .api import fetch_seasons, get_media_streams
+from .api import get_media_streams
 
 REGEX = regex.compile(r"kamyroll://(?:.+?\.)+?crunchyroll\.com/([^&?/]+)")
 
 MEDIA_ID_REGEX = regex.compile(r'\{"isAuthenticated":.+?"mediaId":"(.+?)".+?\}')
 
-
-def fetch_v2_media_id(session, url):
-    return MEDIA_ID_REGEX.search(session.get(url).text).group(1)
+CRUNCHYROLL_EPISODES_REGEX = regex.compile(
+    r"<crunchyroll:mediaId>(\d+)</crunchyroll:mediaId>"
+    r".+?<crunchyroll:episodeTitle>(.+?)</crunchyroll:episodeTitle>"
+    r".+?<crunchyroll:episodeNumber>(\d+)</crunchyroll:episodeNumber>",
+    flags=regex.DOTALL,
+)
 
 
 def extract_streams(session, medias: "list"):
@@ -20,8 +25,8 @@ def extract_streams(session, medias: "list"):
     collected_streams = []
     collected_subtitles = []
 
-    for media in medias:
-        streams = get_media_streams(session, KAMYROLL_API, media["id"])
+    for (media_id, title) in medias:
+        streams = get_media_streams(session, KAMYROLL_API, media_id)
 
         collected_subtitles.extend(
             _["url"] for _ in streams.get("subtitles", []) if _["locale"] == "en-US"
@@ -32,7 +37,7 @@ def extract_streams(session, medias: "list"):
                 collected_streams.append(
                     {
                         "stream_url": stream["url"],
-                        "title": media["title"],
+                        "title": title,
                         **(
                             {"subtitle": collected_subtitles}
                             if collected_subtitles
@@ -44,13 +49,24 @@ def extract_streams(session, medias: "list"):
     return collected_streams
 
 
-def fetcher(session, url, check, match):
-    media_id = fetch_v2_media_id(session, CRUNCHYROLL + match.group(1))
+def get_media_from_rss(session, rss_url):
 
-    for episode, media in fetch_seasons(
+    episodes = defaultdict(list)
+
+    for match in list(CRUNCHYROLL_EPISODES_REGEX.finditer(session.get(rss_url).text))[
+        ::-1
+    ]:
+        episodes[int(match.group(3))].append(match.group(1, 2))
+
+    return episodes
+
+
+def fetcher(session, url, check, match):
+    rss_url = CRUNCHYROLL + match.group(1) + ".rss"
+
+    for episode, medias in get_media_from_rss(
         session,
-        KAMYROLL_API,
-        media_id,
-        predicate=lambda episode: check(episode["episode_number"]),
+        rss_url,
     ).items():
-        yield partial(extract_streams, session, media), episode
+        if check(int(episode)):
+            yield partial(extract_streams, session, medias), episode
